@@ -416,7 +416,7 @@ sub generate_pkgdata {
     # Found a package specific file sorting module
 
     # Add srcdir to package search path
-    unshift(@INC, $srcdir);
+    push @INC, $srcdir;
 
     require MyFilelists;
     $sort = new MyFilelists(list => $master_filelist, flavor => $flavor,
@@ -762,10 +762,9 @@ sub _rtl_files {
   $filessort->extract_libtool_libs();
   $list = $filessort->get_list();
   push @$result, @$list;
-  $filessort->reset();
-  $filessort->extract_perl_modules();
-  $list = $filessort->get_list();
-  push @$result, @$list;
+#  for my $f(@$result) {
+#    print "rtl: $f\n"
+#  }
   $filessort->reset();
   return $result;
 }
@@ -778,15 +777,8 @@ sub _dev_files {
   my $list = $filessort->get_list();
   push @$result, @$list;
   $filessort->reset();
-  $filessort->flavored_headers();
-  $list = $filessort->get_list();
-  push @$result, @$list;
-  $filessort->reset();
-  $filessort->noflavor_headers();
-  $list = $filessort->get_list();
-  push @$result, @$list;
-  $filessort->reset();
-  $filessort->extract_flavor_defs();
+  $filessort->flavored_headers() if defined $mangling;
+  $filessort->noflavor_headers() if ! defined $mangling;
   $filessort->add_package_metadata_files('dev');
   $list = $filessort->get_list();
   push @$result, @$list;
@@ -802,7 +794,7 @@ sub _doc_files {
   return [];
 }
 
-# Autoload methods go after =cut, and are processed by the autosplit program.
+# Autolod methods go after =cut, and are processed by the autosplit program.
 
 1;
 
